@@ -2,7 +2,6 @@ import hashlib
 import itertools
 import re
 import sys
-import warnings
 from collections import defaultdict
 from importlib import import_module
 from types import ModuleType
@@ -10,7 +9,7 @@ from types import ModuleType
 from asgiref.local import Local
 from content_editor.models import Type
 from django.conf import settings
-from django.core.checks import Error, Warning
+from django.core.checks import Error, Info, Warning
 from django.core.exceptions import ValidationError
 from django.core.signals import request_finished
 from django.db import models
@@ -334,14 +333,75 @@ def apps_middleware(get_response):
 
 
 class TemplateType(Type):
+    """
+    Template page type
+
+    Example usage:
+
+    .. code-block:: python
+
+        from feincms3.applications import PageTypeMixin, TemplateType
+        from feincms3.pages import AbstractPage
+        from content_editor.models import Region
+
+        class Page(AbstractPage, PageTypeMixin)
+            TYPES = [
+                TemplateType(
+                    # Required arguments
+                    key="standard",
+                    title="Standard page",
+                    template_name="pages/standard.html",
+                    regions=[
+                        Region(key="main", title="Main"),
+                    ],
+
+                    # You may pass other arguments here, they will be available
+                    # on ``page.type`` as-is.
+                ),
+            ]
+    """
+
     _REQUIRED = {"key", "title", "template_name", "regions", "app_namespace"}
 
     def __init__(self, **kwargs):
+        # Always setting app_namespace makes it easier for PageTypeMixin.save
         kwargs.setdefault("app_namespace", lambda instance: "")
         super().__init__(**kwargs)
 
 
 class ApplicationType(Type):
+    """
+    Application page type
+
+    Example usage:
+
+    .. code-block:: python
+
+        from feincms3.applications import PageTypeMixin, TemplateType
+        from feincms3.pages import AbstractPage
+        from content_editor.models import Region
+
+        class Page(AbstractPage, PageTypeMixin)
+            TYPES = [
+                TemplateType(
+                    # Required arguments
+                    key="standard",
+                    title="Standard page",
+                    urlconf="path.to.urlconf.module",
+
+                    # Optional arguments
+                    template_name="pages/standard.html",
+                    regions=[
+                        Region(key="main", title="Main"),
+                    ],
+                    app_namespace=lambda page: ...,
+
+                    # You may pass other arguments here, they will be available
+                    # on ``page.type`` as-is.
+                ),
+            ]
+    """
+
     _REQUIRED = {"key", "title", "urlconf", "app_namespace"}
 
     def __init__(self, **kwargs):
@@ -547,7 +607,7 @@ class PageTypeMixin(models.Model):
         for type in cls.TYPES:
             if isinstance(type, ApplicationType):
                 try:
-                    import_module(type.urlconf)
+                    module = import_module(type.urlconf)
                 except ModuleNotFoundError as exc:
                     yield Error(
                         f"The application type {type.key!r} has an unimportable"
@@ -555,24 +615,23 @@ class PageTypeMixin(models.Model):
                         obj=cls,
                         id="feincms3.E003",
                     )
-
-    @property
-    def application(self):
-        warnings.warn(
-            "AppsMixin.application is PageTypeMixin.page_type now.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.page_type
-
-    @property
-    def app_instance_namespace(self):
-        warnings.warn(
-            "AppsMixin.app_instance_namespace is PageTypeMixin.app_namespace now.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.app_namespace
+                else:
+                    app_name = getattr(module, "app_name", None)
+                    if type.key != app_name and not getattr(
+                        module, "ignore_app_name_mismatch", False
+                    ):
+                        yield Info(
+                            f"The URLconf module of the application type {type.key!r}"
+                            f" has app_name = {app_name!r} which doesn't match"
+                            " the application key.",
+                            obj=cls,
+                            id="feincms3.I004",
+                            hint=(
+                                "Silence this warning by adding"
+                                " 'ignore_app_name_mismatch = True'"
+                                f" to the {type.urlconf!r} module if this is expected."
+                            ),
+                        )
 
 
 signals.class_prepared.connect(PageTypeMixin.fill_page_type_choices)
