@@ -1,4 +1,7 @@
+import warnings
+
 from django.conf import settings
+from django.core.checks import Warning
 from django.db import models
 from django.db.models import Q, signals
 from django.utils.translation import activate, get_language, gettext_lazy as _
@@ -30,6 +33,26 @@ class MenuMixin(models.Model):
             field.choices = sender.MENUS
             field.default = field.choices[0][0]
 
+    @classmethod
+    def check(cls, **kwargs):
+        errors = super().check(**kwargs)
+        errors.extend(cls._check_feincms3_menu_mixin(**kwargs))
+        return errors
+
+    @classmethod
+    def _check_feincms3_menu_mixin(cls, **kwargs):
+        if invalid := [
+            value
+            for value, label in cls.MENUS
+            if value and (value.startswith("_") or not value.isidentifier())
+        ]:
+            yield Warning(
+                "MenuMixin menus should only use valid public Python identifiers"
+                f" as keys. Invalid: {sorted(invalid)!r}.",
+                obj=cls,
+                id="feincms3.W005",
+            )
+
 
 signals.class_prepared.connect(MenuMixin.fill_menu_choices)
 
@@ -40,6 +63,10 @@ class TemplateMixin(models.Model):
     as pages, articles or anything comparable. The ``TemplateMixin``
     provides a ready-made solution for selecting django-content-editor
     ``Template`` instances through Django's administration interface.
+
+    .. warning::
+       You are encouraged to use the PageTypeMixin and TemplateType from
+       :mod:`feincms3.applications` instead.
     """
 
     template_key = ChoicesCharField(_("template"), max_length=100)
@@ -75,6 +102,14 @@ class TemplateMixin(models.Model):
             field.default = sender.TEMPLATES[0].key
             sender.TEMPLATES_DICT = {t.key: t for t in sender.TEMPLATES}
 
+            warnings.warn(
+                f"{sender._meta.label} uses the TemplateMixin."
+                " It is recommended to use the PageTypeMixin and TemplateType"
+                " from feincms3.applications even if you're not planning to use"
+                " any apps.",
+                DeprecationWarning,
+            )
+
 
 signals.class_prepared.connect(TemplateMixin.fill_template_key_choices)
 
@@ -122,6 +157,24 @@ class LanguageAndTranslationOfMixin(LanguageMixin):
     class Meta:
         abstract = True
 
+    @classmethod
+    def check(cls, **kwargs):
+        errors = super().check(**kwargs)
+        errors.extend(cls._check_feincms3_language_and_translation_of_mixin(**kwargs))
+        return errors
+
+    @classmethod
+    def _check_feincms3_language_and_translation_of_mixin(cls, **kwargs):
+        unique_together = [set(fields) for fields in cls._meta.unique_together]
+        if {"language_code", "translation_of"} not in unique_together:
+            yield Warning(
+                "Models using the LanguageAndTranslationOfMixin should ensure"
+                " that only one translation can be added per language.",
+                obj=cls,
+                id="feincms3.W003",
+                hint='Add ("language_code", "translation_of") to unique_together.',
+            )
+
     def translations(self):
         """
         Return a queryset containing all translations of this object
@@ -148,7 +201,9 @@ class LanguageAndTranslationOfMixin(LanguageMixin):
         Implement the following validation rules:
 
         - Objects in the primary language cannot be the translation of another object
-        - Objects in other languages can only reference objects in the primary language
+        - Objects in other languages can only reference objects in the primary
+          language (this is automatically verified by Django because we're
+          using ``limit_choices_to``)
         """
 
         super().clean_fields(exclude)
@@ -163,19 +218,6 @@ class LanguageAndTranslationOfMixin(LanguageMixin):
                 exclude=exclude,
             )
 
-        if (
-            self.translation_of
-            and self.translation_of.language_code != settings.LANGUAGES[0][0]
-        ):
-            raise validation_error(
-                _(
-                    "Objects may only be the translation of"
-                    " objects in the primary language."
-                ),
-                field="translation_of",
-                exclude=exclude,
-            )
-
 
 class RedirectMixin(models.Model):
     """
