@@ -2,16 +2,16 @@
 Plugin for including template snippets through the CMS
 """
 
-from __future__ import unicode_literals
-
 from collections import defaultdict
 
+from content_editor.admin import ContentEditorInline
 from django.db import models
 from django.db.models import signals
+from django.template.base import Template
 from django.template.loader import render_to_string
 from django.utils.translation import gettext_lazy as _
 
-from content_editor.admin import ContentEditorInline
+from feincms3.mixins import ChoicesCharField
 
 
 __all__ = ("Snippet", "SnippetInline", "render_snippet")
@@ -29,19 +29,15 @@ class Snippet(models.Model):
     Template snippet plugin
     """
 
-    template_name = models.CharField(
-        _("template name"),
-        max_length=200,
-        choices=(("", ""),),  # Non-empty choices for get_*_display
-    )
+    template_name = ChoicesCharField(_("template"), max_length=100)
 
     class Meta:
         abstract = True
-        verbose_name = _("snippet")
-        verbose_name_plural = _("snippets")
+        verbose_name = _("predefined snippet")
+        verbose_name_plural = _("predefined snippets")
 
     def __str__(self):
-        return "{}".format(self.get_template_name_display())
+        return self.get_template_name_display()
 
     @staticmethod
     def fill_template_name_choices(sender, **kwargs):
@@ -66,6 +62,10 @@ class Snippet(models.Model):
         """
         from feincms3.renderer import default_context
 
+        templates = defaultdict(
+            lambda: Template(""),
+            ((row[0], row[0]) for row in cls.TEMPLATES),
+        )
         context_fns = defaultdict(
             lambda: default_context,
             [(row[0], row[2]) for row in cls.TEMPLATES if len(row) > 2],
@@ -73,7 +73,7 @@ class Snippet(models.Model):
 
         renderer.register_template_renderer(
             cls,
-            lambda plugin: plugin.template_name,
+            lambda plugin: templates[plugin.template_name],
             lambda plugin, context: context_fns[plugin.template_name](plugin, context),
         )
 
@@ -87,4 +87,4 @@ class SnippetInline(ContentEditorInline):
     with the other feincms3 plugins
     """
 
-    pass
+    button = '<span class="material-icons">smart_toy</span>'
