@@ -2,9 +2,10 @@ from django import template
 from django.conf import settings
 from django.template.base import Node, TemplateSyntaxError, kwarg_re
 from django.urls import NoReverseMatch
-from django.utils.html import conditional_escape
+from django.utils.html import conditional_escape, mark_safe
 
 from feincms3.applications import reverse_app as _reverse_app
+from feincms3.utils import is_first_party_link
 
 
 register = template.Library()
@@ -155,3 +156,10 @@ def translations(iterable):
         {"code": code, "name": name, "object": translations.get(code)}
         for code, name in settings.LANGUAGES
     ]
+
+
+@register.simple_tag
+def maybe_target_blank(href, *, attributes='target="_blank" rel="noopener"'):
+    if is_first_party_link(href):
+        return ""
+    return mark_safe(attributes)
