@@ -28,6 +28,16 @@ def is_first_party_link(url, *, first_party_hosts=None):
 
     NOTE! ``first_party_hosts`` should not contain port numbers even if using a
     non-standard port, the same is true for Django's ``ALLOWED_HOSTS`` setting.
+
+    One template tag is available to help with ensuring off-site links open in
+    a new window (if you need this...). The template tag does not allow
+    specifying the list of first party hosts (it always uses
+    ``ALLOWED_HOSTS``):
+
+    .. code-block:: html+django
+
+        {% load feincms3 %}
+        <a href="{{ url }}" {% maybe_target_blank url %}>text</a>
     """
     u = urlparse(url)
 
